@@ -38,7 +38,8 @@ mystyle_list_set_property (ASWMProps *wmprops, ASHashTable *list )
     if( !start_hash_iteration( list, &iterator ) ) return ;
 	do
 	{
-        nelements += 9 + 7 + ((MyStyle*)curr_hash_data(&iterator))->gradient.npoints * 4;
+#define MYSTYLE_STATIC_ELEM_NUM (9 + 4 + 2 + 7)
+        nelements += MYSTYLE_STATIC_ELEM_NUM + ((MyStyle*)curr_hash_data(&iterator))->gradient.npoints * 4;
     }while( next_hash_item(&iterator));
 
 	prop = safemalloc (sizeof (CARD32) * nelements);
@@ -59,14 +60,20 @@ mystyle_list_set_property (ASWMProps *wmprops, ASHashTable *list )
 		prop[i++] = style->relief.fore;
 		prop[i++] = style->relief.back;
 		prop[i++] = style->texture_type;
-		prop[i++] = style->max_colors;
+		prop[i++] = style->slice_x_start;
+		prop[i++] = style->slice_x_end;
+		prop[i++] = style->slice_y_start;
+		prop[i++] = style->slice_y_end;
+		prop[i++] = style->blur_x;
+		prop[i++] = style->blur_y;
 		if( style->back_icon.pix == None ) 
 			make_icon_pixmaps( &(style->back_icon), False );
 		prop[i++] = style->back_icon.pix;
 		prop[i++] = style->back_icon.mask;
 		prop[i++] = style->tint;
 		prop[i++] = style->back_icon.alpha;
-		prop[i++] = 0;						   /* unused/reserved */
+		prop[i++] = style->overlay_type;				   
+		prop[i++] = (style->overlay)?XInternAtom (dpy, style->overlay->name, False): None;		
 		prop[i++] = style->gradient.npoints;
 		{
 			int           k;
@@ -83,7 +90,7 @@ mystyle_list_set_property (ASWMProps *wmprops, ASHashTable *list )
 		}
     }while( next_hash_item(&iterator));
 	/* set the property version to 1.2 */
-    set_as_style (wmprops, nelements *  sizeof (CARD32), (1 << 8) + 2, prop );
+    set_as_style (wmprops, nelements *  sizeof (CARD32), (1 << 8) + 5, prop );
     free (prop);
 }
 
@@ -106,7 +113,7 @@ mystyle_get_property (ASWMProps *wmprops)
 	/* do we know how to handle this version? */
     version = wmprops->as_styles_version ;
     /* do we know how to handle this version? */
-	if (version != (1 << 8) + 2)
+	if (version != (1 << 8) + 5)
 	{
         show_error("style property has unknown version %d.%d", (int)version >> 8, (int)version & 0xff);
 		return;
@@ -158,7 +165,11 @@ mystyle_get_property (ASWMProps *wmprops)
 			}
 #else
 			name = XGetAtomName (dpy, prop[i + 3]);
-			load_font (name, &style->font);
+#if 1			
+			set_string( &(style->font.name), mystrdup(name)); 
+#else
+			load_font( name, &(style->font) );
+#endif			
 			XFree (name);
             style->user_flags |= F_FONT;
             style->inherit_flags &= ~F_FONT;
@@ -166,20 +177,33 @@ mystyle_get_property (ASWMProps *wmprops)
 		}
 		style->colors.fore = prop[i + 4];
 		style->colors.back = prop[i + 5];
-        LOCAL_DEBUG_OUT( "style(%p:\"%s\")->colors(#%lX,#%lX)->flags(0x%lX)->inherit_flags(0x%X)", style, style->name, style->colors.fore, style->colors.back, flags, style->inherit_flags );
+        LOCAL_DEBUG_OUT( "style(%p:\"%s\")->colors(#%lX,#%lX)->flags(0x%lX)->inherit_flags(0x%lX)", style, style->name, style->colors.fore, style->colors.back, flags, style->inherit_flags );
 		style->relief.fore = prop[i + 6];
 		style->relief.back = prop[i + 7];
 		style->texture_type = prop[i + 8];
-		style->max_colors = prop[i + 9];
-		back_pix = prop[i + 10];
-		back_mask = prop[i + 11];
-		style->tint = prop[i + 12];
-		back_alpha = prop[i + 13];
+		style->slice_x_start = prop[i + 9];
+		style->slice_x_end = prop[i + 10];
+		style->slice_y_start = prop[i + 11];
+		style->slice_y_end = prop[i + 12];
+		style->blur_x = prop[i + 13];
+		style->blur_y = prop[i + 14];
+LOCAL_DEBUG_OUT( "style(%p:\"%s\")->slicing( x: %d to %d, y: %d to %d )", style, style->name, style->slice_x_start, style->slice_x_end, style->slice_y_start, style->slice_y_end );
+		back_pix = prop[i + 15];
+		back_mask = prop[i + 16];
+		style->tint = prop[i + 17];
+		back_alpha = prop[i + 18];
         set_flags(style->user_flags, F_EXTERNAL_BACKPIX|F_EXTERNAL_BACKMASK);
-		/* unused/reserved : */
-/*    style->tint = prop[i + 14];
- */
-		style->gradient.npoints = prop[i + 15];
+        LOCAL_DEBUG_OUT( "overlay props = %lu, 0x%lX", prop[i + 19], prop[i + 20] );
+	    style->overlay_type = prop[i + 19];
+		if( prop[i + 20] != None ) 
+		{
+			name = XGetAtomName (dpy, prop[i + 20]);
+			style->overlay = mystyle_find (name);			
+			XFree (name);
+		}
+
+ 
+		style->gradient.npoints = prop[i + 21];
 /*	  show_warning( "checking if gradient data in style \"%s\": (set flags are : 0x%X)", style->name, style->inherit_flags);
  */
 		if (style->gradient.npoints > 0 )
@@ -192,12 +216,12 @@ mystyle_get_property (ASWMProps *wmprops)
 
 			for (k = 0; k < style->gradient.npoints; k++)
  			{
-				style->gradient.color[k] = prop[i + 16 + k * 4 + 0];
+				style->gradient.color[k] = prop[i + MYSTYLE_STATIC_ELEM_NUM + k * 4 + 0];
 				/*
 				   style->gradient.color[k].green = prop[i + 16 + k * 4 + 1];
 				   style->gradient.color[k].blue = prop[i + 16 + k * 4 + 2];
 				 */
-				style->gradient.offset[k] = (double)prop[i + 16 + k * 4 + 3] / 0x1000000;
+				style->gradient.offset[k] = (double)prop[i + MYSTYLE_STATIC_ELEM_NUM+ k * 4 + 3] / 0x1000000;
                 LOCAL_DEBUG_OUT ("gradient color at offset %f is %lX", style->gradient.offset[k],
 								 style->gradient.color[k]);
 			}
@@ -229,8 +253,8 @@ mystyle_get_property (ASWMProps *wmprops)
 			}
 		}
 
-		i += 9 + 7 + style->gradient.npoints * 4;
-		LOCAL_DEBUG_OUT( "user_flags = 0x%X, inherit_flags = 0x%X", style->user_flags, style->inherit_flags );
+		i += MYSTYLE_STATIC_ELEM_NUM + style->gradient.npoints * 4;
+		LOCAL_DEBUG_OUT( "user_flags = 0x%lX, inherit_flags = 0x%lX", style->user_flags, style->inherit_flags );
 		style->set_flags = style->user_flags | style->inherit_flags;
 	}
 
