@@ -26,6 +26,7 @@
 #include "../../configure.h"
 
 #include "asinternals.h"
+#include "../../libAfterConf/afterconf.h"
 
 /********************************************************************/
 /* ASWindow frame decorations :                                     */
@@ -248,12 +249,12 @@ check_frame_canvas( ASWindow *asw, Bool required )
 
             /* create windows */
             valuemask = CWBorderPixel | CWCursor | CWEventMask ;
-            /*if( Scr.asv->visual_info.visual == DefaultVisual( dpy, Scr.screen ) )
-            {*/
+            if( Scr.asv->visual_info.visual == DefaultVisual( dpy, Scr.screen ) )
+            {
 			/* only if root has same depth and visual as us! */
-                attributes.background_pixmap = None;
+                attributes.background_pixmap = ParentRelative;
                 valuemask |= CWBackPixmap;
-            /*}*/
+            }
             attributes.border_pixel = Scr.asv->black_pixel;
             attributes.cursor = Scr.Feel.cursors[ASCUR_Default];
             attributes.event_mask = AS_FRAME_EVENT_MASK;
@@ -267,7 +268,7 @@ check_frame_canvas( ASWindow *asw, Bool required )
 				bw = asw->hints->border_width ;
 			asw->status->frame_border_width = bw ;
             w = create_visual_window (Scr.asv, (ASWIN_DESK(asw)==Scr.CurrentDesk)?Scr.Root:Scr.ServiceWin, 
-									  0, 0, 
+									  asw->status->x, asw->status->y, 
 									  asw->status->width, asw->status->height,
                                       bw, InputOutput, valuemask, &attributes);
 			XLowerWindow( dpy, w );
@@ -364,8 +365,10 @@ LOCAL_DEBUG_OUT( "--DESTR Client(%lx(%s))->CLIENT->canvas(%p)->window(%lx)", asw
          * since that would cause a transition to the Withdrawn state.
 		 */
 #if 1
-        if( !ASWIN_GET_FLAGS(asw, AS_Dead) && get_parent_window( w ) == asw->frame )
+        if( (asw->status == NULL || !get_flags(asw->status->flags, AS_Dead)) && 
+			get_parent_window( w ) == asw->frame )
         {
+			LOCAL_DEBUG_OUT( "reparenting client window %lX", w );
             if( get_flags( AfterStepState, ASS_Shutdown ) )
                 quietly_reparent_window( w, Scr.Root, xwc.x, xwc.y, AS_CLIENT_EVENT_MASK );
             else
@@ -399,12 +402,12 @@ check_icon_canvas( ASWindow *asw, Bool required )
             attributes.border_pixel = Scr.asv->black_pixel;
             attributes.cursor = Scr.Feel.cursors[ASCUR_Default];
 
-            if ((ASWIN_HFLAGS(asw, AS_ClientIcon|AS_ClientIconPixmap) != AS_ClientIcon) ||
+            if ((get_flags(asw->hints->client_icon_flags, AS_ClientIcon|AS_ClientIconPixmap) != AS_ClientIcon) ||
                  asw->hints == NULL || asw->hints->icon.window == None ||
                  !get_flags(Scr.Feel.flags, KeepIconWindows))
             { /* create windows */
                 attributes.event_mask = AS_ICON_TITLE_EVENT_MASK;
-                w = create_visual_window ( Scr.asv, (ASWIN_DESK(asw)==Scr.CurrentDesk)?Scr.Root:Scr.ServiceWin, -10, -10, 1, 1, 0,
+                w = create_visual_window ( Scr.asv, (ASWIN_DESK(asw)==Scr.CurrentDesk)?Scr.Root:Scr.ServiceWin, -9000, -9000, 1, 1, 0,
                                            InputOutput, valuemask, &attributes );
                 canvas = create_ascanvas( w );
             }else
@@ -422,6 +425,8 @@ LOCAL_DEBUG_OUT( "++CREAT Client(%lx(%s))->ICON->canvas(%p)->window(%lx)", asw->
     {                                          /* destroy canvas here */
         w = canvas->w ;
 LOCAL_DEBUG_OUT( "--DESTR Client(%lx(%s))->ICON->canvas(%p)->window(%lx)", asw->w, ASWIN_NAME(asw)?ASWIN_NAME(asw):"noname", canvas, canvas->w );
+		if( asw->icon_title_canvas == canvas ) 
+			asw->icon_title_canvas = NULL ;
         destroy_ascanvas( &canvas );
         if( asw->hints && asw->hints->icon.window == w )
             unregister_aswindow( w );
@@ -463,7 +468,7 @@ check_icon_title_canvas( ASWindow *asw, Bool required, Bool reuse_icon_canvas )
             attributes.cursor = Scr.Feel.cursors[ASCUR_Default];
             attributes.event_mask = AS_ICON_TITLE_EVENT_MASK;
             /* create windows */
-            w = create_visual_window ( Scr.asv, (ASWIN_DESK(asw)==Scr.CurrentDesk)?Scr.Root:Scr.ServiceWin, -10, -10, 1, 1, 0,
+            w = create_visual_window ( Scr.asv, (ASWIN_DESK(asw)==Scr.CurrentDesk)?Scr.Root:Scr.ServiceWin, -9010, -9010, 1, 1, 0,
                                        InputOutput, valuemask, &attributes );
 
             register_aswindow( w, asw );
@@ -478,49 +483,30 @@ LOCAL_DEBUG_OUT( "++CREAT Client(%lx(%s))->ICONT->canvas(%p)->window(%lx)", asw-
     return canvas;
 }
 
-ASImage*
-get_window_icon_image( ASWindow *asw )
+/* pointers should point to valid values preset to 0, im.width, 0, im.height */
+static void
+geometry2slicing( ASGeometry g, int *pxs, int *pxe,  int *pys,  int *pye)
 {
-	ASImage *im = NULL ;
-    if( asw )
-    {
-        if( ASWIN_HFLAGS( asw, AS_ClientIcon|AS_ClientIconPixmap ) == (AS_ClientIcon|AS_ClientIconPixmap) &&
-            get_flags( Scr.Feel.flags, KeepIconWindows )&&
-            asw->hints->icon.pixmap != None )
-        {/* convert client's icon into ASImage */
-            unsigned int width, height ;
-            get_drawable_size( asw->hints->icon.pixmap, &width, &height );
-            im = picture2asimage( Scr.asv, asw->hints->icon.pixmap,
-                                        asw->hints->icon_mask,
-                                        0, 0, width, height,
-                                        0xFFFFFFFF, False, 100 );
-            LOCAL_DEBUG_OUT( "converted client's pixmap into an icon %dx%d %p", width, height, im );
-        }
-        /* TODO: we also need to check for newfashioned ARGB icon from
-        * extended WM specs here
-        */
-        if( im == NULL )
-        {
-            if( asw->hints->icon_file )
-            {
-                im = get_asimage( Scr.image_manager, asw->hints->icon_file, 0xFFFFFFFF, 100 );
-                LOCAL_DEBUG_OUT( "loaded icon from \"%s\" into %dx%d %p", asw->hints->icon_file, im?im->width:0, im?im->height:0, im );
-            }else
-            {
-                LOCAL_DEBUG_OUT( "no icon to use %s", "" );
-            }
-        }
-    }
-	return im;
+	if (get_flags(g.flags,XValue))
+		*pxs = get_flags(g.flags,XNegative)?*pxe+g.x:g.x; 
+	if (get_flags(g.flags,YValue))
+		*pys = get_flags(g.flags,YNegative)?*pye+g.y:g.y; 
+
+	if (get_flags(g.flags,WidthValue))
+		*pxe = *pxs + g.width; 
+	if (get_flags(g.flags,HeightValue))
+		*pye = *pys + g.height; 
 }
 
+
 static ASTBarData*
 check_tbar( ASTBarData **tbar, Bool required, const char *mystyle_name,
             ASImage *img, unsigned short back_w, unsigned short back_h,
             int flip, ASFlagType align,
             ASFlagType fbevel, ASFlagType ubevel,
             unsigned char fcm, unsigned char ucm,
-            int context )
+            int context,
+			ASGeometry *slicing )
 {
     if( required )
     {
@@ -533,12 +519,19 @@ LOCAL_DEBUG_OUT( "++CREAT tbar(%p)->context(%s)", *tbar, context2text(context) )
 
 		set_astbar_flip( *tbar, flip );   
 
+		invalidate_astbar_style (*tbar, -1);
         set_astbar_style( *tbar, BAR_STATE_FOCUSED, mystyle_name );
         set_astbar_style( *tbar, BAR_STATE_UNFOCUSED, "default" );
         if( img )
         {
             LOCAL_DEBUG_OUT("adding bar icon %p %ux%u", img, img->width, img->height );
-            add_astbar_icon( *tbar, 0, 0, flip, align, img );
+			if (slicing && slicing->flags)
+			{
+				int xs = 0, xe = 0, ys = img->width, ye = img->height;
+				geometry2slicing( *slicing, &xs, &xe, &ys, &ye);
+	            add_astbar_image( *tbar, 0, 0, flip, align, img, xs, xe, ys, ye );
+    		}else
+	            add_astbar_icon( *tbar, 0, 0, flip, align, img );
             if( back_w == 0 )
                 back_w = get_flags(flip,FLIP_VERTICAL)?img->height:img->width ;
             if( back_h == 0 )
@@ -568,6 +561,22 @@ invalidate_window_icon( ASWindow *asw )
         check_icon_canvas( asw, False );
 }
 
+void 
+invalidate_window_mystyles( ASWindow *asw )
+{
+	int i ; 
+	
+	for( i = 0 ; i < FRAME_PARTS ; ++i ) 
+		if( asw->frame_bars[i] ) 
+			invalidate_astbar_style (asw->frame_bars[i], -1);
+    if( asw->tbar )
+		invalidate_astbar_style (asw->tbar, -1);
+    if( asw->icon_button )
+		invalidate_astbar_style (asw->icon_button, -1);
+	if( asw->icon_title )
+		invalidate_astbar_style (asw->icon_title, -1);
+}
+
 /***********************************************************************
  *  grab_aswindow_buttons - grab needed buttons for all of the windows
  *  for specified client
@@ -776,19 +785,26 @@ check_allowed_function (FunctionData *fdata, ASHints *hints)
     int i ;
     ComplexFunction *cfunc ;
 
-    if (func != F_FUNCTION)
+    if ( func != F_FUNCTION && func != F_CATEGORY )
         return check_allowed_function2 (func, hints);
 
-    if( (cfunc = get_complex_function( fdata->name ) ) == NULL )
-        return 0;
+	if( func == F_FUNCTION )
+	{	
+    	if( (cfunc = get_complex_function( fdata->name ) ) == NULL )
+        	return 0;
 
-    for( i = 0 ; i < cfunc->items_num ; ++i )
-        if( cfunc->items[i].func == F_FUNCTION )
-        {
-            if( check_allowed_function (&(cfunc->items[i]), hints) == 0 )
-                return 0;
-        }else if( check_allowed_function2 (cfunc->items[i].func, hints) == 0 )
-            return 0;
+    	for( i = 0 ; i < cfunc->items_num ; ++i )
+        	if( cfunc->items[i].func == F_FUNCTION || cfunc->items[i].func == F_CATEGORY )
+        	{
+            	if( check_allowed_function (&(cfunc->items[i]), hints) == 0 )
+                	return 0;
+        	}else if( check_allowed_function2 (cfunc->items[i].func, hints) == 0 )
+            	return 0;
+	}else if( func == F_CATEGORY ) 
+	{
+		if( name2desktop_category( fdata->text?fdata->text:fdata->name, NULL ) == NULL ) 
+			return 0;
+	}	 
     return 1;
 }
 
@@ -887,7 +903,6 @@ fix_background_align( ASFlagType align )
 	return new_align;
 }
 
-
 Bool
 hints2decorations( ASWindow *asw, ASHints *old_hints )
 {
@@ -898,7 +913,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
     ASOrientation *od = get_orientation_data(asw);
     char *mystyle_name = Scr.Look.MSWindow[BACK_FOCUSED]->name;
     char *frame_mystyle_name = NULL ;
-    int *frame_contexts  = &(od->frame_contexts[0]);
+    unsigned int *frame_contexts  = &(od->frame_contexts[0]);
 	Bool tbar_created = False;
 	Bool status_changed = False ;
 
@@ -908,6 +923,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
     check_icon_canvas( asw, (ASWIN_HFLAGS( asw, AS_Icon) && !get_flags(Scr.Feel.flags, SuppressIcons)) );
 
 	/* 4) we need to prepare icon title window : */
+	LOCAL_DEBUG_CALLER_OUT( "checking icon title canvas(%p)", asw->icon_title_canvas );
 	check_icon_title_canvas( asw, (ASWIN_HFLAGS( asw, AS_IconTitle) &&
                                    get_flags(Scr.Feel.flags, IconTitle) &&
 								  !get_flags(Scr.Feel.flags, SuppressIcons)),
@@ -939,7 +955,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
         check_side_canvas( asw, od->sbar_side, False );
         check_side_canvas( asw, od->left_side, False );
         check_side_canvas( asw, od->right_side, False );
-    }else if( frame != old_frame || (get_flags( old_hints->flags, AS_Handles ) != ASWIN_HFLAGS(asw, AS_Handles)))
+    }else if( frame != old_frame || (old_hints && get_flags( old_hints->flags, AS_Handles ) != ASWIN_HFLAGS(asw, AS_Handles)))
 	{
 	    check_side_canvas( asw, od->sbar_side, myframe_has_parts(frame, FRAME_BTM_MASK) );
   		check_side_canvas( asw, od->left_side, myframe_has_parts(frame, FRAME_LEFT_MASK) );
@@ -965,7 +981,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 	{
 		if( old_hints )
 		{
-			icon_image_changed = (ASWIN_HFLAGS( asw, AS_ClientIcon|AS_ClientIconPixmap ) != get_flags(old_hints->flags, AS_ClientIcon|AS_ClientIconPixmap));
+			icon_image_changed = (get_flags(asw->hints->client_icon_flags, AS_ClientIcon|AS_ClientIconPixmap ) != get_flags(old_hints->client_icon_flags, AS_ClientIcon|AS_ClientIconPixmap));
 			if( !icon_image_changed )
         		icon_image_changed = (asw->hints->icon.pixmap != old_hints->icon.pixmap );
 			if( !icon_image_changed )
@@ -974,13 +990,13 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 
 		if( icon_image_changed )
 		{
-			ASImage *icon_image = get_window_icon_image( asw );
+			ASImage *icon_image = get_client_icon_image( ASDefaultScr, asw->hints ); 
     		check_tbar( &(asw->icon_button), (asw->icon_canvas != NULL), AS_ICON_MYSTYLE,
             		    icon_image, Scr.Look.ButtonWidth, Scr.Look.ButtonHeight,/* scaling icon image */
                 		0, Scr.Look.ButtonAlign,
                 		Scr.Look.ButtonBevel, Scr.Look.ButtonBevel,
                 		TEXTURE_TRANSPIXMAP_ALPHA, TEXTURE_TRANSPIXMAP_ALPHA,
-                		C_IconButton );
+                		C_IconButton, False );
 			
 			if( icon_image )
     	    	safe_asimage_destroy( icon_image );
@@ -999,7 +1015,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 				AS_ICON_TITLE_MYSTYLE,
   	            NULL, 0, 0, 0, ALIGN_CENTER, DEFAULT_TBAR_HILITE, DEFAULT_TBAR_HILITE,
               	TEXTURE_TRANSPIXMAP_ALPHA, TEXTURE_TRANSPIXMAP_ALPHA,
-              	C_IconTitle );
+              	C_IconTitle, False );
     
 	if( asw->icon_title )
     {
@@ -1007,8 +1023,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 	    add_astbar_label( asw->icon_title, 0, 0, 0, frame->title_align,
 							DEFAULT_TBAR_HSPACING, DEFAULT_TBAR_VSPACING,
 						    ASWIN_ICON_NAME(asw),
-							(asw->hints->icon_name_idx < 0)?AS_Text_ASCII :
-							asw->hints->names_encoding[asw->hints->icon_name_idx]);
+							ASWIN_ICON_NAME_ENC(asw));
 	    set_astbar_style( asw->icon_title, BAR_STATE_FOCUSED, AS_ICON_TITLE_MYSTYLE );
   	    set_astbar_style( asw->icon_title, BAR_STATE_UNFOCUSED, AS_ICON_TITLE_UNFOCUS_MYSTYLE );
     }
@@ -1074,22 +1089,32 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
                         	od->flip, frame->part_align[i],
                         	frame->part_fbevel[i], frame->part_ubevel[i],
                         	TEXTURE_TRANSPIXMAP_ALPHA, TEXTURE_TRANSPIXMAP_ALPHA,
-                        	frame_contexts[i] );
+                        	frame_contexts[i], (i<FRAME_SIDES)?&(frame->part_slicing[i]):NULL );
 	      	}
     	}else
         	for( i = 0 ; i < FRAME_PARTS ; ++i )
-            	check_tbar( &(asw->frame_bars[i]), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT );
+            	check_tbar( &(asw->frame_bars[i]), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT, NULL );
 
     	check_tbar( &(asw->tbar), has_tbar, mystyle_name, NULL, 0, 0,
 					od->flip,
 					frame->title_align,
                 	frame->title_fbevel, frame->title_ubevel,
                 	frame->title_fcm, frame->title_ucm,
-                	C_TITLE );
+                	C_TITLE, NULL );
 		if( asw->tbar ) 
 		{	
-			set_astbar_huesat( asw->tbar, BAR_STATE_FOCUSED, frame->title_fhue, frame->title_fsat );
-			set_astbar_huesat( asw->tbar, BAR_STATE_UNFOCUSED, frame->title_uhue, frame->title_usat );
+			int fhue = -1, fsat = -1, uhue = -1, usat = -1 ; 
+			if( get_flags( frame->set_title_attr, MYFRAME_TitleFHueSet )  ) 
+				fhue = frame->title_fhue ;
+			if( get_flags( frame->set_title_attr, MYFRAME_TitleFSatSet )  ) 
+				fsat = frame->title_fsat ;
+			if( get_flags( frame->set_title_attr, MYFRAME_TitleUHueSet )  ) 
+				uhue = frame->title_fhue ;
+			if( get_flags( frame->set_title_attr, MYFRAME_TitleUSatSet )  ) 
+				usat = frame->title_fsat ;
+				
+			set_astbar_huesat( asw->tbar, BAR_STATE_FOCUSED, fhue, fsat );
+			set_astbar_huesat( asw->tbar, BAR_STATE_UNFOCUSED, uhue, usat );
 		}
 
 		tbar_created = (asw->tbar != NULL);
@@ -1141,7 +1166,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 			{
 				ASCanvas *canvas = ASWIN_HFLAGS(asw, AS_VerticalTitle)?asw->frame_sides[FR_W]:asw->frame_sides[FR_N];
 	        	/* label ( goes on top of above pixmap ) */
-	        	if( change_astbar_first_label( asw->tbar, asw->hints->names[0], asw->hints->names_encoding[0] ) )
+	        	if( change_astbar_first_label( asw->tbar, ASWIN_NAME(asw), ASWIN_NAME_ENCODING(asw) ) )
   		        	if( canvas )
       		    	{
 	                	render_astbar( asw->tbar, canvas );
@@ -1171,11 +1196,22 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 				if( frame->title_backs[i] && frame->title_backs[i]->image )
 				{
                     LOCAL_DEBUG_OUT( "Adding Title Back #%d", i );
-                    add_astbar_icon( asw->tbar,
-                             	tbar_layout_col[ASO_TBAR_ELEM_LBTN+i],
-                             	tbar_layout_row[ASO_TBAR_ELEM_LBTN+i],
-                             	od->flip, fix_background_align(frame->title_backs_align[i]),
-                             	frame->title_backs[i]->image);
+					if (frame->title_backs_slicing[i].flags != 0)
+					{
+						ASImage *im = frame->title_backs[i]->image;
+						int xs = 0, xe = 0, ys = im->width, ye = im->height;
+						geometry2slicing( frame->title_backs_slicing[i], &xs, &xe, &ys, &ye);
+                    	add_astbar_image( asw->tbar,
+                             		tbar_layout_col[ASO_TBAR_ELEM_LBTN+i],
+                             		tbar_layout_row[ASO_TBAR_ELEM_LBTN+i],
+                             		od->flip, fix_background_align(frame->title_backs_align[i]),
+                             		im, xs, xe, ys, ye);
+					}else
+                    	add_astbar_icon( asw->tbar,
+                             		tbar_layout_col[ASO_TBAR_ELEM_LBTN+i],
+                             		tbar_layout_row[ASO_TBAR_ELEM_LBTN+i],
+                             		od->flip, fix_background_align(frame->title_backs_align[i]),
+                             		frame->title_backs[i]->image);
 					if( i == MYFRAME_TITLE_BACK_RTITLE_SPACER ) 
 						rtitle_spacer_added = True ;
 					else if( i == MYFRAME_TITLE_BACK_LTITLE_SPACER ) 
@@ -1214,7 +1250,7 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
                           tbar_layout_row[ASO_TBAR_ELEM_LBL],
                           od->flip,
                           title_align, frame->title_h_spacing, frame->title_v_spacing,
-                          asw->hints->names[0], asw->hints->names_encoding[0]);
+                          ASWIN_NAME(asw), ASWIN_NAME_ENCODING(asw));
 		
 			/* all the buttons go after the label to be rendered over it */
 			/* left buttons : */
@@ -1243,13 +1279,19 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
       		    {
           		    char *str = list_functions_by_context (C_TButton0<<i, asw->hints);
               		LOCAL_DEBUG_OUT( "balloon text will be \"%s\"", str?str:"none" );
-	                set_astbar_balloon( asw->tbar, C_TButton0<<i, str, AS_Text_ASCII );
+	                set_astbar_balloon2( asw->tbar, TitlebarBalloons, C_TButton0<<i, str, AS_Text_ASCII );
   		            if( str )
       		            free( str );
           		}
       		}
 		}
 	}
+	
+	if( ASWIN_HFLAGS( asw, AS_WindowOpacity ) )
+	{
+		set_32bit_property (asw->frame, _XA_NET_WM_WINDOW_OPACITY, XA_CARDINAL, asw->hints->window_opacity );
+	}	 
+
 
     /* we also need to setup label, unfocused/sticky style and tbar sizes -
      * it all is done when we change windows state, or move/resize it */
@@ -1260,14 +1302,18 @@ hints2decorations( ASWindow *asw, ASHints *old_hints )
 		/* we need to map all the possibly created subwindows if window is not iconic */
 		if( !ASWIN_GET_FLAGS(asw, AS_Iconic ) )
 		{
-			LOCAL_DEBUG_OUT("mapping frame subwindows for client %lX, frame canvas = %p", asw->w, asw->frame_canvas );
-			XMapSubwindows(dpy, asw->frame);
+			for( i = 0 ; i < FRAME_SIDES ; ++i )
+				map_canvas_window( asw->frame_sides[i], False );
+
+/*			LOCAL_DEBUG_OUT("mapping frame subwindows for client %lX, frame canvas = %p", asw->w, asw->frame_canvas );
+			XMapSubwindows(dpy, asw->frame); */
 		}else
 		{
 			map_canvas_window( asw->icon_canvas, False );
 			map_canvas_window( asw->icon_title_canvas, False );
 		}
 	}
+
 	return	status_changed ;
 }
 
@@ -1287,12 +1333,12 @@ LOCAL_DEBUG_OUT( "as?w(%p)->free_res(%d)", asw, free_resources );
     if(  free_resources || asw->hints == NULL || asw->status == NULL )
     {/* destroy window decorations here : */
      /* destruction goes in reverese order ! */
-        check_tbar( &(asw->icon_title),  False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT );
-        check_tbar( &(asw->icon_button), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT );
-        check_tbar( &(asw->tbar),        False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT );
+        check_tbar( &(asw->icon_title),  False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT, NULL );
+        check_tbar( &(asw->icon_button), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT, NULL );
+        check_tbar( &(asw->tbar),        False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT, NULL );
 		i = FRAME_PARTS ;
 		while( --i >= 0 )
-            check_tbar( &(asw->frame_bars[i]), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT );
+            check_tbar( &(asw->frame_bars[i]), False, NULL, NULL, 0, 0, 0, 0, 0, 0, 0, 0, C_NO_CONTEXT, NULL );
 
         check_side_canvas( asw, FR_W, False );
         check_side_canvas( asw, FR_E, False );
@@ -1389,7 +1435,9 @@ SetShape (ASWindow *asw, int w)
 			/* add clients shape */
 			combine_canvas_shape_at_geom (asw->frame_canvas, asw->client_canvas, child_x, child_y, width, height, bw );
 
+#ifndef NO_DEBUG_OUTPUT
 			print_shape( asw->frame_canvas->shape ) ;
+#endif
 			/* apply shape */
 			update_canvas_display_mask (asw->frame_canvas, True);
 			set_flags( asw->internal_flags, ASWF_PendingShapeRemoval );
